@@ -5,12 +5,12 @@ set -e
 set -x
 
 FREETYPE_VERSION="VER-2-13-2"
-POPPLER_VERSION="poppler-25.02.0"
+POPPLER_VERSION="poppler-25.04.0"
 LIBICAL_VERSION="v3.0.17"
-LIBXML_VERSION="v2.12.2"
-ZXING_VERSION="v2.1.0"
-KF_VERSION="v6.11.0"
-GEAR_VERSION="master"
+LIBXML_VERSION="v2.12.7"
+ZXING_VERSION="v2.3.0"
+KF_VERSION="v6.13.0"
+GEAR_VERSION="release/25.04"
 
 function build_cmake_module() {
     local repo=$1
@@ -31,13 +31,12 @@ function build_cmake_module() {
 
     mkdir build
     cd build
-    cmake -DBUILD_SHARED=ON \
-        -DBUILD_TESTING=OFF -DBUILD_SHARED_LIBS=OFF \
+    cmake -DBUILD_TESTING=OFF \
+        -DBUILD_SHARED_LIBS=OFF \
         -DCMAKE_PREFIX_PATH=$STAGING_ROOT \
         -DCMAKE_INSTALL_PREFIX=$STAGING_ROOT \
         -DCMAKE_EXE_LINKER_FLAGS="-Wl,--as-needed" \
         -DZLIB_USE_STATIC_LIBS=ON \
-        -DKF_SKIP_PO_PROCESSING=ON \
         -DUSE_DBUS=OFF \
         $@ -DCMAKE_BUILD_TYPE=Release ..
 
@@ -81,17 +80,17 @@ build_cmake_module https://github.com/nu-book/zxing-cpp.git zxing-cpp $ZXING_VER
 
 # KDE Frameworks
 build_kf_module frameworks/extra-cmake-modules
-build_kf_module frameworks/karchive -DWITH_BZIP2=OFF -DWITH_LIBLZMA=OFF -DWITH_LIBZSTD=OFF
-build_kf_module frameworks/kcodecs
-build_kf_module frameworks/kconfig -DKCONFIG_USE_QML=OFF
-build_kf_module frameworks/kcoreaddons -DKCOREADDONS_USE_QML=OFF
-build_kf_module frameworks/ki18n -DBUILD_WITH_QML=OFF -DKI18N_EMBEDDED_ISO_CODES_CACHE=ON
-build_kf_module frameworks/kcalendarcore
-build_kf_module frameworks/kcontacts
+build_kf_module frameworks/karchive -DWITH_BZIP2=OFF -DWITH_LIBLZMA=OFF -DWITH_LIBZSTD=OFF -DKF_SKIP_PO_PROCESSING=ON
+build_kf_module frameworks/kcodecs -DKF_SKIP_PO_PROCESSING=ON
+build_kf_module frameworks/kconfig -DKCONFIG_USE_QML=OFF -DKF_SKIP_PO_PROCESSING=ON
+build_kf_module frameworks/kcoreaddons -DKCOREADDONS_USE_QML=OFF -DKF_SKIP_PO_PROCESSING=ON
+build_kf_module frameworks/ki18n -DBUILD_WITH_QML=OFF -DKI18N_EMBEDDED_ISO_CODES_CACHE=ON -DKF_SKIP_PO_PROCESSING=ON
+build_kf_module frameworks/kcalendarcore -DKF_SKIP_PO_PROCESSING=ON
+build_kf_module frameworks/kcontacts -DKF_SKIP_PO_PROCESSING=ON
 
 # PIM
-build_kde_module pim/kmime
-build_kde_module pim/kpkpass
+build_kde_module pim/kmime -DKF_SKIP_PO_PROCESSING=ON
+build_kde_module pim/kpkpass -DKF_SKIP_PO_PROCESSING=ON
 
 export CXXFLAGS="-static-libstdc++ -static-libgcc"
 build_kde_module $CI_PROJECT_PATH -DKITINERARY_STANDALONE_CLI_EXTRACTOR=ON -DBUILD_TOOLS=OFF
