@@ -20,6 +20,7 @@
 #include <KContacts/Address>
 
 #include <QDebug>
+#include <QRegularExpression>
 #include <QUrl>
 #include <QUrlQuery>
 
@@ -127,6 +128,27 @@ GeoCoordinates LocationUtil::geo(const QVariant &location)
     return {};
 }
 
+GeoCoordinates LocationUtil::geoFromUrl(const QUrl &url)
+{
+    if (url.host().contains(QLatin1StringView("google"))) {
+        QRegularExpression regExp(
+            QStringLiteral("[/=@](-?\\d+\\.\\d+),(-?\\d+\\.\\d+)"));
+        auto match = regExp.match(url.path());
+        if (!match.hasMatch()) {
+            match = regExp.match(url.query());
+        }
+
+        if (match.hasMatch()) {
+            const auto latitude = match.capturedView(1).toDouble();
+            const auto longitude = match.capturedView(2).toDouble();
+
+            return GeoCoordinates{latitude, longitude};
+        }
+    }
+
+    return {};
+}
+
 PostalAddress LocationUtil::address(const QVariant &location)
 {
     if (JsonLd::canConvert<Place>(location)) {
@@ -161,7 +183,7 @@ int LocationUtil::distance(const GeoCoordinates &coord1, const GeoCoordinates &c
 }
 
 // see https://en.wikipedia.org/wiki/Haversine_formula
-int LocationUtil::distance(float lat1, float lon1, float lat2, float lon2)
+int LocationUtil::distance(double lat1, double lon1, double lat2, double lon2)
 {
     const auto degToRad = M_PI / 180.0;
     const auto earthRadius = 6371000.0; // in meters
